'use strict';


const util     = require('util');
const url      = require('url');
const co       = require('co');

const extract = require('meta-extractor');

const oembetter = require('oembetter')();

const doExtract = (url) => {
    return new Promise((resolve, reject) => {
        extract({ uri: url }, (err, res) => {
            if (err) { reject(err); }
            else { resolve(res); }
        });
    })
};

oembetter.addAfter((url, options, response, callback) => {
    doExtract(url)
    .then(result => {
        response.metadata = result;
        callback();
    })
    .catch(err => { callback(); });
});

oembetter.addFallback(function(url, options, callback) {
    doExtract(url)
    .then(result => {
        callback(undefined, {
            metadata: result
        });
    })
    .catch(err => { callback(err); });
});

/* oembetter.endpoints([
  { domain: 'instagram.com', endpoint: 'http://api.instagram.com/oembed' },
  { domain: 'facebook.com', path: /\/videos\//, endpoint: 'https://www.facebook.com/plugins/video/oembed.json/' },
  { domain: 'facebook.com', path: /\/video.php\//, endpoint: 'https://www.facebook.com/plugins/video/oembed.json/' },
  { domain: 'facebook.com', path: /\/posts\//, endpoint: 'https://www.facebook.com/plugins/post/oembed.json/' },
  { domain: 'facebook.com', path: /\/activity\//, endpoint: 'https://www.facebook.com/plugins/post/oembed.json/' },
  { domain: 'facebook.com', path: /\/photo.php\//, endpoint: 'https://www.facebook.com/plugins/post/oembed.json/' },
  { domain: 'facebook.com', path: /\/photos\//, endpoint: 'https://www.facebook.com/plugins/post/oembed.json/' },
  { domain: 'facebook.com', path: /\/permalink.php\//, endpoint: 'https://www.facebook.com/plugins/post/oembed.json/' },
  { domain: 'facebook.com', path: /\/media\//, endpoint: 'https://www.facebook.com/plugins/post/oembed.json/' },
  { domain: 'facebook.com', path: /\/questions\//, endpoint: 'https://www.facebook.com/plugins/post/oembed.json/' },
  { domain: 'facebook.com', path: /\/notes\//, endpoint: 'https://www.facebook.com/plugins/post/oembed.json/' },
]); */
// oembetter.endpoints(oembetter.suggestedEndpoints);

/*
NOTES:

Generally we want to support simple embedding .... except ... the most common thing in
the websites is framed-embed.

The framed-embed tag splits out a bunch of metadata to grasp the TITLE
and the DESCRIPTION and some other independent items.  That data is available via OpenGraph
tags in the web page.  Hence Metaphor or url-engine can get that data.

framed-embed needs to call Metaphor

everything else needs to use oembetter


Another method:-

Simply use oembetter, and an AFTER filter that looks up additional things in OpenGraph tags



*/

module.exports = co.wrap(function* (embedurl) {
    return yield new Promise((resolve, reject) => {
            oembetter.fetch(embedurl,
            (err, result) => {
                if (err) return reject(err);
                else resolve(result);
            }
            );
        });
});

module.exports(process.argv[2])
.then(result => {
    console.log(util.inspect(result));
})
.catch(err => {
    console.error(err);
});
